@@ -135,19 +135,11 @@ impl<I: Tokens> Parser<I> {
                 break;
             }
 
-            match kind {
-                // Recover
-                // const enum D {
-                //     d = 10
-                //     g = 11
-                // }
-                ParsingContext::EnumMembers => {
-                    const TOKEN: &Token = &Token::Comma;
-                    let cur = format!("{:?}", cur!(self, false).ok());
-                    self.emit_err(self.input.cur_span(), SyntaxError::Expected(TOKEN, cur));
-                    continue;
-                }
-                _ => {}
+            if kind == ParsingContext::EnumMembers {
+                const TOKEN: &Token = &Token::Comma;
+                let cur = format!("{:?}", cur!(self, false).ok());
+                self.emit_err(self.input.cur_span(), SyntaxError::Expected(TOKEN, cur));
+                continue;
             }
             // This will fail with an error about a missing comma
             expect!(self, ',');
@@ -192,20 +184,14 @@ impl<I: Tokens> Parser<I> {
         debug_assert!(self.input.syntax().typescript());
 
         let init = self.parse_ident_name()?;
-        match init {
-            // Handle
-            //
-            // var a: void.x
-            //            ^
-            Ident {
-                sym: js_word!("void"),
-                ..
-            } => {
-                let dot_start = cur_pos!(self);
-                let dot_span = span!(self, dot_start);
-                self.emit_err(dot_span, SyntaxError::TS1005)
-            }
-            _ => {}
+        if let Ident {
+            sym: js_word!("void"),
+            ..
+        } = init
+        {
+            let dot_start = cur_pos!(self);
+            let dot_span = span!(self, dot_start);
+            self.emit_err(dot_span, SyntaxError::TS1005)
         }
         let mut entity = TsEntityName::Ident(init);
         while eat!(self, '.') {
@@ -1091,8 +1077,7 @@ impl<I: Tokens> Parser<I> {
             ..cloned.ctx()
         };
         cloned.set_ctx(ctx);
-        let res = op(&mut cloned);
-        res
+        op(&mut cloned)
     }
 
     /// `tsIsUnambiguouslyStartOfFunctionType`
@@ -1132,10 +1117,8 @@ impl<I: Tokens> Parser<I> {
             return Ok(true);
         }
 
-        if (is!(self, '{') || is!(self, '[')) {
-            if self.parse_binding_pat_or_ident().is_ok() {
-                return Ok(true);
-            }
+        if (is!(self, '{') || is!(self, '[')) && self.parse_binding_pat_or_ident().is_ok() {
+            return Ok(true);
         }
 
         Ok(false)
@@ -1244,7 +1227,7 @@ impl<I: Tokens> Parser<I> {
         let params = vec![TsFnParam::Ident(id)];
 
         let ty = self.try_parse_ts_type_ann()?;
-        let type_ann = if let Some(ty) = ty { Some(ty) } else { None };
+        let type_ann = ty;
 
         self.parse_ts_type_member_semicolon()?;
         Ok(Some(TsIndexSignature {
@@ -2343,10 +2326,7 @@ impl<I: Tokens> Parser<I> {
         self.try_parse_ts(|p| {
             let start = cur_pos!(p);
             let opt = p.parse_ts_decl(start, decorators, value, true)?;
-            Ok(match opt {
-                Some(v) => Some(v),
-                None => None,
-            })
+            Ok(opt)
         })
     }
 
@@ -2590,7 +2570,7 @@ impl<I: Tokens> Parser<I> {
         let ty = parse_constituent_type(self)?;
         trace_cur!(self, parse_ts_union_or_intersection_type__after_first);
 
-        if self.input.is(&operator) {
+        if self.input.is(operator) {
             let mut types = vec![ty];
 
             while self.input.eat(operator) {
